@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
-__version__ = "1.0.7"
+__version__ = "1.0.8"
 
 import os
 import sys
 
 
 def get_swagger_jmx_version():
+    """
+
+    :return:
+    """
     pip_pkg_dir = os.path.join(os.path.dirname(__file__), "..", "..")
     pip_pkg_dir = os.path.abspath(pip_pkg_dir)
 
@@ -19,4 +23,4 @@ def get_swagger_jmx_version():
 def show_version():
     sys.stdout.write(get_swagger_jmx_version())
     sys.stdout.write(os.linesep)
-    sys.exit()
\ No newline at end of file
+    sys.exit()
